package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````R!8``#0```!@E@````0`!30`(``'
M`"@`'``;``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````D)``
M`)"0```%```````!``$```"0D```D)`!`)"0`0"X`@``-`,```8```````$`
M`@```)R0``"<D`$`G)`!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&2LB@``K(H``*R*```$`0``!`$```0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$````RIH[!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-VAF`````&$```!L```````````````Q````#@``````````
M````.0````\```!!`````````#```````````P```$\```!D`````````"``
M``!.````!@```!X````5`````````$0```!9````8``````````8````/0``
M`%L```!E`````````&@```!J````+P```!,```!:````1@```!8```!?````
M2`````````!+````1P```#8```!>````)@```"H`````````!P```%``````
M````#````"P```!K````70```$T````A````40```&D`````````8@``````
M```9````+@```$(````````````````````2````,P`````````*````8P``
M`"L`````````"0`````````D````.@````````!2````!0```$D````<````
M/`````````````````````````!,`````````#L```!5````9@````````!G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!0`````````
M`````````````````````````````````````",````B`````````"D`````
M````"P```"<````H````+0``````````````#0`````````=````&P```#4`
M```:```````````````1`````````#0````R````.````!\`````````````
M``````````````````0```````````````````!#````)0``````````````
M`````!<`````````0````$4````(````````````````````/P````````!4
M``````````````!8```````````````^````5P````````!3`````````$H`
M```0``````````````!6````7````#<```!A````````````````````````
M````````````R!8````````#``L``````)B0`0```````P`1`)D`````````
M`````!(````,```````````````2````%```````````````$@```'H#``"0
M(0``"````!(`"P`<```````````````B````*P``````````````$@```$,#
M`````````````!(````Q```````````````2````BP,``$B3`0``````$``5
M`#@``````````````!(```"9`P``8"P``!@````2``L`/P``````````````
M$@```%`#`````````````!(```!'```````````````2````M`,``$`W``!<
M````$@`+`(H``````````````!(```#(`P``Q),!```````0`!4`3P``````
M````````$@```,`#``!(DP$``````!``%`!?```````````````2````;@``
M````````````$@```'0``````````````!(```![```````````````2````
MA0``````````````$@```(\``````````````!(```#'`P``Q),!```````0
M`!4`F```````````````$@```%<"`````````````!(```">````````````
M```2````I0``````````````$@```+,``````````````!(```#$````````
M```````1````T0``````````````$@```-,#```4)```)````!(`"P#@`P``
M."0``%`````2``L`[`,``-0M``#(!@``$@`+`-\``````````````!8```#R
M```````````````2````8@,`````````````$@```/T``````````````!(`
M```&`0``P),!``0````1`!4`#@$`````````````$@```!<!````````````
M`!(````Y`P`````````````2````(P$`````````````$@```"H!````````
M`````!(```#Y`P``^$,```@!```2``L`/0$`````````````$0```$\!````
M`````````!(```!?`0`````````````2````;0$`````````````$@```'(!
M`````````````!$```"!`0`````````````2````!`0``$23`0`$````$0`4
M`)`!`````````````!(```"<`0`````````````2````L0$`````````````
M$@```+P!`````````````!(```!U`P``Q),!```````0`!4`^@(`````````
M````$@```,\!`````````````!(```!'!```R!8````````2``L`W0$`````
M````````$@```.4!`````````````"(```#]`0`````````````2````"0(`
M````````````$@````X$``#$DP$``````!``%0`6!```B"0``#@%```2``L`
M#P(`````````````(@```"4"`````````````!(````P`@`````````````2
M````(P0```!%``!0`0``$@`+`$$"`````````````!(````M!```2),!````
M```0`!4`.00``+P@``!<````$@`+`$$$```@1P``M`(``!(`"P!(`@``````
M```````2````1@0``,@6````````$@`+`$\"`````````````!(```!.!```
MF"$``'P"```2``L`6P0``'@L``!<`0``$@`+`%8"`````````````!(```!M
M!```P"D``)0````2``L`7P(`````````````$@```'`"`````````````!(`
M``#C`@`````````````2````=P(`````````````$@```'L$``!4*@``9```
M`!(`"P"&`@`````````````2````CP(`````````````$@```)4"````````
M`````!(````L`P`````````````2````F@(`````````````$@```!\#``"$
MDP$`!````!$`%0"B`@`````````````2````5P,`````````````$@```*D"
M`````````````!(```"#!```G$,``%P````2``L`L`(`````````````$@``
M`+\"`````````````!$````4`P```),!``0````1`!0`C`0``)PT``"D`@``
M$@`+`#8!`````````````!(```#$`@`````````````2````:0,`````````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA
M;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T
M870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y`'!E<FQ?9&5S
M=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET
M,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A
M8V-E<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K
M`&UE;6-M<`!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P
M<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M
M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!S=')D=7``;&EB<'1H<F5A9"YS
M;RXQ`'!T:')E861?871F;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M;7E?<&%R7W!L`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS
M."XP+V5A<FUV-VAF+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K
M9R]L:6(``)"0`0`7````E)`!`!<```"DD@$`%P```+22`0`7````Q)(!`!<`
M``#0D@$`%P```-B2`0`7````Z)(!`!<```#PD@$`%P```/B2`0`7````_)(!
M`!<`````DP$`%P````23`0`7````%),!`!<````8DP$`%P```""3`0`7````
M)),!`!<````HDP$`%P```"R3`0`7````,),!`!<````XDP$`%P```#R3`0`7
M````1),!`!<```"HD@$`%0<``+"2`0`5%```N)(!`!4B``"\D@$`$2<``,"2
M`0`2)P``S)(!`!4R``#4D@$`%38``-R2`0`5/```X)(!`!5"``#DD@$`%4<`
M`.R2`0`55@``])(!`!5F``"8D0$`%@,``)R1`0`6!```H)$!`!8%``"DD0$`
M%@<``*B1`0`6"```K)$!`!8)``"PD0$`%@H``+21`0`6#```N)$!`!8.``"\
MD0$`%@\``,"1`0`6$```Q)$!`!82``#(D0$`%A8``,R1`0`6%P``T)$!`!88
M``#4D0$`%AD``-B1`0`6&@``W)$!`!8;``#@D0$`%AT``.21`0`6'@``Z)$!
M`!8?``#LD0$`%B```/"1`0`6(0``])$!`!8C``#XD0$`%B@``/R1`0`6*0``
M`)(!`!8J```$D@$`%BP```B2`0`6+0``#)(!`!8N```0D@$`%B\``!22`0`6
M,```&)(!`!8S```<D@$`%C0``""2`0`6-0``))(!`!8W```HD@$`%CD``"R2
M`0`6.@``,)(!`!8[```TD@$`%CX``#B2`0`6/P``/)(!`!9!``!`D@$`%D(`
M`$22`0`60P``2)(!`!9$``!,D@$`%D<``%"2`0`62```5)(!`!9)``!8D@$`
M%DL``%R2`0`63P``8)(!`!91``!DD@$`%E0``&B2`0`65P``;)(!`!98``!P
MD@$`%ED``'22`0`66P``>)(!`!9<``!\D@$`%ET``("2`0`67@``A)(!`!9?
M``"(D@$`%F$``(R2`0`68@``D)(!`!9C``"4D@$`%F4``)B2`0`6:0``G)(!
M`!9J``"@D@$`%FL```3@+>4$X)_E#N"/X`CPON7L?0$``,:/XA?*C.+L_;SE
M`,:/XA?*C.+D_;SE`,:/XA?*C.+<_;SE`,:/XA?*C.+4_;SE`,:/XA?*C.+,
M_;SE`,:/XA?*C.+$_;SE`,:/XA?*C.*\_;SE`,:/XA?*C.*T_;SE`,:/XA?*
MC.*L_;SE`,:/XA?*C.*D_;SE`,:/XA?*C.*<_;SE`,:/XA?*C.*4_;SE`,:/
MXA?*C.*,_;SE`,:/XA?*C.*$_;SE`,:/XA?*C.)\_;SE`,:/XA?*C.)T_;SE
M`,:/XA?*C.)L_;SE`,:/XA?*C.)D_;SE`,:/XA?*C.)<_;SE`,:/XA?*C.)4
M_;SE`,:/XA?*C.),_;SE`,:/XA?*C.)$_;SE`,:/XA?*C.(\_;SE`,:/XA?*
MC.(T_;SE`,:/XA?*C.(L_;SE`,:/XA?*C.(D_;SE`,:/XA?*C.(<_;SE`,:/
MXA?*C.(4_;SE`,:/XA?*C.(,_;SE`,:/XA?*C.($_;SE`,:/XA?*C.+\_+SE
M`,:/XA?*C.+T_+SE`,:/XA?*C.+L_+SE`,:/XA?*C.+D_+SE`,:/XA?*C.+<
M_+SE`,:/XA?*C.+4_+SE`,:/XA?*C.+,_+SE`,:/XA?*C.+$_+SE`,:/XA?*
MC.*\_+SE`,:/XA?*C.*T_+SE`,:/XA?*C.*L_+SE`,:/XA?*C.*D_+SE`,:/
MXA?*C.*<_+SE`,:/XA?*C.*4_+SE`,:/XA?*C.*,_+SE`,:/XA?*C.*$_+SE
M`,:/XA?*C.)\_+SE`,:/XA?*C.)T_+SE`,:/XA?*C.)L_+SE`,:/XA?*C.)D
M_+SE`,:/XA?*C.)<_+SE`,:/XA?*C.)4_+SE`,:/XA?*C.),_+SE`,:/XA?*
MC.)$_+SE`,:/XA?*C.(\_+SE`,:/XA?*C.(T_+SE`,:/XA?*C.(L_+SE`,:/
MXA?*C.(D_+SE`,:/XA?*C.(<_+SE`,:/XA?*C.(4_+SE`,:/XA?*C.(,_+SE
M`,:/XA?*C.($_+SE`,:/XA?*C.+\^[SE`,:/XA?*C.+T^[SE`,:/XA?*C.+L
M^[SE`,:/XA?*C.+D^[SE`,:/XA?*C.+<^[SE`!"@X0(`H.$'T,WC,P``ZD0P
MG^5$()_E`S"/X'!`+>D\4)_E`F"3YP50C^`&`%7A<("]*`%@1N(`0*#C!6!&
MX"9AH.$$,)7D,_\OX08`5.$!0(3B^O__&G"`O>BD>@$`&`$``)QY`0!D()_E
M9#"?Y600G^4"((_@`P"2YP$PDN<#`%#A'O\O(?!!+>D!<$/B`'!'X`A0@.(`
M0*#CIW&@X0<``.H(8!7E"%"%X@`PEN4S_R_A!P!4X0%`A.(``(;E\(&]"`0P
M5>6@`%/C]/__"BC__^M(>@$`/`$``"`!``!P@9_E`&!1XH!`+>D(@(_@"-!-
MXDL```I<(9_E7#&?Y0(@F.<`8(+E"""6Y0-PF.<`,);E`""'Y0`@D^4``%+C
M.@``"C@1G^4!$)CG`""!Y0`@D^4`,-+E``!3XP4```H!((+B+P!3XP`@@04!
M,-+D``!3X_K__QH``%#C````"OC^_^N3___K^#"?Y0,PF.<``%/C-0``"NPP
MG^7L4)_E`Y"8YP50C^`)`%7A`9!),@6023``0*`S*9&@,00``"H$,)7D,_\O
MX0D`5.$!0(3B^O__&K@`G^6X4)_E``"/X.#^_^NP,)_E!5"/X`.`F.<(`%7A
M`8!(,@6`2#``0*`S*(&@,00``"H$,)7D,_\OX00`6.$!0(3B^O__&@`@E^4`
M$);E!`"6Y9(+`.NR_O_K3#"?Y60@G^4#,)CG`B"/X``@@^7+___J5#"?Y1/`
MH.,$`*#C`!"@XP,PC^`"(*#C`,"-Y?O^_^L!`*#CV/[_ZX3__^O'___JT'D!
M`&0!```X`0``;`$``%P!```H`0``/'@!`$S^___X=P$`1`$``)1Z`0#,,```
M\$<MZ0"04.+$,)_E`S"/X"L```J\()_E`C"3YP"`D^4``%CC*```"@!0V>4!
M<*#A``!5XST`51,!4*`3`%"@`Q$``!H`0)CE``!4XPP```H(8*#A!`"@X04@
MH.$)$*#AD_[_ZP``4.,"```:!3#4YST`4^,+```*!$"VY0``5./S__\:!`"@
MX?"'O>@)4*#A`3#UY0``4^,]`%,3^___&@E01>#F___J`5"%X@A@1N`%0(3@
M1F&@X0!@A^4$`*#A\(>]Z`E`H.'M___J"$"@X>O__^HH>`$`.`$``&`AG^5@
M,9_E`B"/X/!#+>D`4%#B`S"2YZ303>(`,)/EG#"-Y0`PH.,"```*`##5Y0``
M4^,*```:,"&?Y2@QG^4"((_@`S"2YP`@D^6<,)WE`B`SX``PH.-!```:I-"-
MXO"#O>B7_O_K`$!0XO'__PK\@)_E#7"@X0B`C^`$`*#A`O__ZP``4.,G```*
M#3#0Y0U@@.(N`%/C`@``&@$PUN4``%/C]/__"@TPT.4N`%/C(@``"@4`H.'H
M_O_K`)"@X08`H.'E_O_K``")X`(`@.+H_O_K!C"@X04@H.$($*#A`&"@X=3^
M_^L'$*#A!@"@X5/^_^L!`'#C!@"@X0,```H(,)WE#SH#X@$)4^,2```*0O[_
MZP8`H.$W_O_K!`"@X=K^_^L``%#CU___&@0`H.%>_O_K!0"@X1K^_^N]___J
M`3#6Y2X`4^/9__\:`C#6Y0``4^/(__\*U?__ZJ?__^OK___J1?[_ZU!W`0!`
M`0``&'<!`'0O``"0()_ED#"?Y0(@C^`00"WIH-!-X@,PDN<`0*#A#1"@X0`P
MD^6<,(WE`#"@XR#^_^L``%#C``"@$P0``!H(,)WE#SH#X@H*4^,!"5,3"@``
M"D@@G^5`,)_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C!P``&J#0C>(0@+WH
M`A"@XP0`H.%M_O_K$`]OX:`"H.'N___J&_[_Z]AU`0!``0``B'4!```0H.'X
M`)_E,$`MZ0';3>+P,)_E#-!-X@``C^`$4(WB`2N@XP,PD.<%`*#A`#"3Y00T
MC>4`,*#CUOW_ZP$P0.(#`%7A"```*@4@C>(`$*#C`@``Z@(`4.$`$,#E`@``
M"@$P<.4O`%/C^?__"B\0H.,%`*#AUOW_ZP``4.,0```*!0!0X0`PH(,`,,"%
M!0"@X5#^_^MP()_E:#"?Y0(@C^`#,)+G`""3Y00TG>4"(#/@`#"@XQ$``!H!
MVXWB#-"-XC"`O>A$()_E.#"?Y0(@C^`#,)+G`""3Y00TG>4"(#/@`#"@XP4`
M`!HD`)_E``"/X`';C>(,T(WB,$"]Z#7^_^K7_?_K)'4!`$`!``"@=`$`<'0!
M`+0L``#P0"WI`&"@X?@`G^4!VTWB]#"?Y0S03>(``(_@!'"-X@%0H.'_(P#C
M`S"0YP<0H.'8`)_E`#"3Y00TC>4`,*#C``"/X,_]_^L`P%#B%P``V@%`3.(!
M.X3B"#"#X@,PC>`$-%/E``!3XR,``!H``%3C#@``"@0@H.$O$*#C!P"@X07^
M_^L``%#C"```"H``G^4``(_@)_[_ZP0PH.$'(*#A!A"@X0``D.4'_O_K!@``
MZF``G^4``(_@'O[_ZP4@H.$&$*#A``"0Y:+]_^M(()_E-#"?Y0(@C^`#,)+G
M`""3Y00TG>4"(#/@`#"@XP0``!H!VXWB#-"-XO"`O>@,0*#AV___ZI#]_^L,
M=`$`0`$``(`L``#$=`$`H'0!`%!S`0#P1RWI`4"@X0`PT>4(T$WB#!*?Y0!0
MH.$((I_E/0!3XP$0C^`!0(0"_(&?Y0(@D><$`*#A"("/X``@DN4$((WE`""@
MX_#]_^L-$*#A`&"@X04`H.&=_O_K`)!0XD$```KI_?_K``!6X3@``)J\,9_E
M`'"=Y0.`F.<'<:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@X0$@\^4`
M`%+C/0!2$_O__QH%,$/@`@"&X@!@F.4#`(#@V?W_ZP``4.,'`(;G%@``"@`0
MG>4%`*#A`""8Y0$PT.0!$9+G``!3XST`4Q,`,,'E!@``"@$@@>(!,-#D`A"@
MX0``4^,]`%,3`3#"Y/G__QH!(*#A/3"@XP`PP>4!,-3D``!3XP$PXN7[__\:
M""&?Y?@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,U```:"-"-XO"'O>@!
MD$GB`3#4Y```4^,!,.GE^___&N[__^K`,)_E`X"8YP!PF.4`,)?E``!3XR0`
M``H',*#A!""SY0D0H.$!D(GB``!2X_K__QH#$('B`1&@X9`PG^4#,(_@`""3
MY0``4N,/```:`0"@X0$@H.,`((/EE_W_ZP"@4.+5__\*!Q"@X0EQH.$'(*#A
MU_S_ZP"@B.4!,(GB`""@XP,ABN<`D(WEH?__Z@<`H.',_/_K``!0XP"@H.$`
M`(CEQ?__"@EQH.'R___J`Y"@X0@0H./?___J`?W_Z^1R`0!``0``T'(!`#@!
M``#8<0$`A',!`$`@G^5`,)_E0`"?Y0(@C^!P0"WI``"/X`-@DN=N_?_K+%"?
MY2Q`G^4%4(_@!B"@X01`C^`%,*#A!!"@X7!`O>@``)#E&?W_ZKQP`0`D`0``
MY'$!`*QI``!(*0``7`"?Y3!`+>D``(_@%-!-XE!0G^59_?_K!5"/X`!`H.$`
M`)#EWO__ZP`0E.4X()_E``"@XS0PG^4,$(WE,!"?Y0,PC^`"()7G`1"/X`0`
MC>4`,(WE#`"=Y1C]_^L4T(WB,("]Z)1Q`0!4<`$`<`$``+PK``#P*`````"@
MXQ[_+^%$(I_E1#*?Y?!/+>D"((_@2]Y-X@!0H.$,T$WB,`*?Y0,PDN<88(WB
M``"/X`%PH.$$$$;B`#"3Y;0TC>4`,*#CW/W_ZR\0H.,`0*#A!0"@X8+\_^L`
M`%#C$```"O0!G^4%$*#A``"/X![__^L%`*#AY"&?Y=0QG^4"((_@`S"2YP`@
MD^6T-)WE`B`SX``PH.-L```:2]Z-X@S0C>+PC[WH!P"@X??\_^NP$9_E`1"/
MX*#\_^L`H%#BY___"@`PVN6<D9_EG(&?Y0``4^.8<9_E"9"/X`B`C^`'<(_@
M/@``"@``5.,$```*"A"@X00`H.$(_?_K``!0XRX```H*`*#A^_S_ZP$@0.(`
M,*#A`B"*X`"PH.$"`%KA`#"*,`$`BC(`$*`S`P``.@@``.H#`%#A`!##Y0(`
M``H!('/E+P!2X_G__PH*`*#AZ?S_ZP"PH.$%`*#AYOS_ZPL`@.`!`(#B`0M0
MX[S__RJTL(WB_!"?Y0<PH.$!*Z#C`1"/X`L`H.$$$(WE`!"@XPA0C>4`H(WE
M@/S_ZP80H.$+`*#A3?S_ZP``4.,#```:(#"=Y0\Z`^(""5/C%```"K00G^4`
M`*#C`1"/X%O\_^L`H%#BHO__"@`PVN4``%/CP/__&@``5.,5```*`##4Y2X`
M4^,"```*`;"@XPF@H.'4___J`3#4Y0``4^/K__\*^/__Z@$0H.,+`*#AC/S_
MZP``4./E__\:4`"?Y0L0H.$``(_@K?[_ZPL`H.&3_/_KC/__Z@&PH.,(H*#A
MP?__ZC'\_^O@;P$`0`$``*@H``!X*```=&\!`$`H``"`)P``?"<``!@H``#4
M)@``+"<``+0F```00"WI+Q"@XP!`H.']^__K``!0XP%`@!($`*#A$$"]Z'G\
M_^H00"WI`$!0X@D```H`,-3E``!3XP8```J-_/_K`0"`X@$+4.,&``"*!`"@
MX1!`O>CV_?_J$`"?Y1!`O>@``(_@:/S_Z@``H.,0@+WH="4``,@DG^7(-)_E
M`B"/X'!`+>D(T$WBO&2?Y0,PDN<-0*#AM%2?Y09@C^``,)/E!#"-Y0`PH.,%
M4(_@!!"@X08`H.$@_?_K``!0XPX```J,-)_E`!"=Y0,PE><`()/E`3&"X`0`
MD^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I49)_E!F"/
MX`00H.$&`*#A"OW_ZP``4.,.```*-#2?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E
M``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J`&2?Y09@C^`$
M$*#A!@"@X?3\_^L``%#C#@``"MPSG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``
M4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZJQCG^4&8(_@!!"@
MX08`H.'>_/_K``!0XPX```J$,Y_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C
M`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^I88Y_E!F"/X`00H.$&
M`*#AR/S_ZP``4.,.```*+#.?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!
M@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___J!&.?Y09@C^`$$*#A!@"@
MX;+\_^L``%#C#@``"M0RG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G
M\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZK!BG^4&8(_@!!"@X08`H.&<
M_/_K``!0XPX```I\,I_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'_
M_PH$,(/B!""3Y0``4N,$((/D^___&NO__^I<8I_E!F"/X`00H.$&`*#AAOS_
MZP``4.,.```*)#*?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKK___J"&*?Y09@C^`$$*#A!@"@X7#\_^L`
M`%#C#@``"LPQG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P
M@^($()/E``!2XP0@@^3[__\:Z___ZK1AG^4&8(_@!!"@X08`H.%:_/_K``!0
MXPX```IT,9_E`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B
M!""3Y0``4N,$((/D^___&NO__^I@89_E!F"/X`00H.$&`*#A1/S_ZP``4.,.
M```*'#&?Y0`0G>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@
MD^4``%+C!""#Y/O__QKK___J#`&?Y000H.$``(_@+_S_ZP`04.("```*^`"?
MY0``C^!V_?_K\`"?Y000H.$``(_@)OS_ZP`04.("```*W`"?Y0``C^!M_?_K
MU`"?Y000H.$``(_@'?S_ZP`04.(2```*P`"?Y0``C^!D_?_KN""?Y60PG^4"
M((_@`S"2YP`@D^4$,)WE`B`SX``PH.,0```:F!"?Y9@`G^4!$(_@``"/X`C0
MC>)P0+WH5/W_ZH0`G^4$$*#A``"/X`3\_^L`$%#BZ?__"G``G^4``(_@2_W_
MZ^7__^K4^O_K]&P!`$`!``#D)0``R&P!`#@!``"()0``."4``.PD``"<)```
M5"0``)PC``"P(P``9",``!@C``!((@``<"(``$0B``!@(@``+"$``%`B``"$
M(0``D&@!`"PB``"<(0``_"$``(PA``!\()_E?#"?Y0(@C^!X`)_E!.`MY0S0
M3>(#,)+G``"/X`T0H.$`,)/E!#"-Y0`PH./6^__K``!0XP4```H``-#E``!0
MXS``4!,!`*`#``"@$P$`(.(T()_E*#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@
M`#"@XP$``!H,T(WB!/"=Y)GZ_^N\9P$`0`$``/@@``!H9P$`3,"?Y0\`+>D,
MP(_@1!"?Y03@+>4,T$WB`1"<YQ0@C>(T,)_E-`"?Y0`0D>4$$(WE`!"@XP,P
MC^``((WE$!"=Y0``D^>P`(#BV?K_Z_\`H.,^^O_K*&<!`$`!``#\9@$`:`$`
M`/!/+>D!V$WB@.&?Y1S03>)\P9_E`A"@XP[@C^``$(WE`1B-X@`@H.,,P)[G
M`#"@XQ00@>(`D*#A`,"<Y0#`@>4`P*#CT/K_ZP%@4.(`@,'BR"^@X0(P)N`"
M,%/@<S#_Y@(P(^`",%/@`B#"X`-@5N`"@,C@``!8XST``+H4L9_E"*"@XQ!Q
MG^4,4(WB"["/X`&@0.,'<(_@`!"@XP8@H.$(,*#A"0"@X0`0C>6V^O_K`0!Q
MXP$`<`,P```*"B"@X040H.$)`*#A;?K_ZP$`<.,?```*!P!0XR```)H(`$#B
M`$"5X`,``#H<``#J`4!$X@4`5.$9```Z"""@XP<0H.$$`*#AE/K_ZP``4./V
M__\:!4!$X`8`E.#$'ZC@?,"?Y0$XC>)H()_E%#"#X@S`C^`"()SG`,"2Y0`@
MD^4,P#+@`""@XQ```!H!V(WB'-"-XO"/O>A(`)_E``"/X([__^L!:%;B`(#(
MX@$`>.,!"'8#R/__&@``X.,`$*#AYO__Z@L`H.&$___KR___ZACZ_^NT9@$`
M0`$```0@``"T9P$`H&4!`$@?```00"WI@OK_ZWOZ_^L``%#C``"0%1"`O>@P
M(9_E\$`MZ0(@C^`H89_E%-!-XB0QG^4($(WB!F"/X`!0H.$#,)+G!@"@X0`P
MD^4,,(WE`#"@XR;[_^L`0%#B`@``"@`PU.4``%/C#@``&NP@G^7D,)_E`B"/
MX`,PDN<`()/E##"=Y0(@,^``,*#C+P``&LP`G^4%$*#A``"/X!30C>+P0+WH
M7OS_Z@40H.&W^?_K``!0XPH```JH()_EF#"?Y0(@C^`#,)+G`""3Y0PPG>4"
M(#/@`#"@XQP``!H4T(WB\("]Z`4`H.%0^O_K`'"@X00`H.%-^O_K``"'X`(`
M@.)0^O_K8#"?Y6`0G^4%(*#A`S"/X`!`C>4!$(_@`$"@X3GZ_^M(()_E+#"?
MY0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XP00H`$&`*`!TO__"K[Y_^L$90$`
MT!X``$`!``"T9`$`<!X``&AD`0`8'0``%!T``/QC`0`\%I_E/,:?Y3PFG^4!
M$(_@#,"/X/!/+>D,,(SB`B"1YT??3>(`D*#A&%",X@`@DN44(8WE`""@XQAP
MC>('`)/H,."-XC#`C.(D0(WB%&"-XOBEG^4'`(?H"J"/X`\`M>@/`*[H`P"5
MZ`,`CN@'`)SH!P"$Z`80H.'4!9_E``"/X+WZ_^L`4%#B`@``"@`PU>4``%/C
M"0$`&GO__^L`4%#B[0``"@4`H.$"^O_K@`"@X0$`@.(%^O_K`"#5Y0``4N,`
M@*#A"0``"HBUG^4(0*#A"["/X`0`H.$+$*#A[/G_ZP$@]>4"0(3B``!2X_C_
M_QID!9_E-%"-X@``C^`"``#J!`"5Y```4.,-```*!A"@X9GZ_^L`0%#B^/__
M"@`PU.4``%/C]?__"BC[_^L``%#C\O__"@0`H.'#^?_K`$!0XA,``!H`4*#C
M1C^-X@4Q@^``01/E``!4XPP```H!L(7B"[&'X``PU.4``%/C!P``"@0`H.$!
M4(7B%/O_ZP``4.,W```:!$";Y```5./T__\:`$"@XP0`H.'&^?_K`%"@X0@`
MH.'#^?_K`%"%X`%;A>($4(7B!0"@X<3Y_^N<-)_EG!2?Y00@H.$#,(_@`#"-
MY9`TG^4!$(_@!("-Y0,PC^``<*#AJOG_ZP<=H.,'`*#A>OG_ZP$`<..%```*
M2!"-X@<`H.$>^?_K`$!0XAD```I4!)_E!S"@X5`4G^4`4*#C`""9Y0``FN<!
M$(_@L`"`XA_Y_^LX))_E##2?Y0(@C^`#,)+G`""3Y10QG>4"(#/@`#"@X_D`
M`!H%`*#A1]^-XO"/O>@$`*#A=_G_ZP!`4.*T__\*QO__ZE`PG>4/.@/B`0E3
MX^'__QID@)WE@_G_ZP``6.'=__\:4#"=Y5,PZ.<'#5/CV?__&@4`H.&'^?_K
M!A"@X0!0H.&X`Y_E``"/X"WZ_^L`$%#BD0``"@``F>4[_/_K`(!0XHT```H(
M`*#A=/G_ZP,`4.,`8*#A#```FH03G^4$`$#B``"(X`$0C^!U^?_K``!0XP4`
M`!H$`%;CNP``"@9@B.`%,%;E+P!3X[<```HP_O_K`&!0X@0``!H(`*#A!A"@
MX4_Y_^L`@%#B=0``&C03G^4T`Y_E`1"/X#"3G^4``(_@+(.?Y5+[_^LH8Y_E
M+/G_ZR0CG^4D,Y_E"9"/X"`3G^4"((_@`S"/X`0@C>4!$(_@!R"@X0B`C^`&
M8(_@``"-Y04`H.$\^?_K#0``Z@3Y_^L`,)#E$0!3XPX``!H8^?_K`4"$X@DP
MH.$'(*#A"!"@X5``C>D`P*#A!0"@X0#`C>4M^?_K!QV@XP4`H.']^/_K`0!P
MX^S__PH'`*#AEOC_ZZ`"G^4%$*#A``"/X"C[_^L%`*#AI/[_ZX?__^KH^/_K
M`#"0Y1$`4^-U__\*`$"9Y>/X_^LX$I_E!S"@X0!0H.,$(*#A`,"0Y0$`FN=8
M$I_EL`"`X@#`C>4!$(_@EOC_ZW7__^H%L*#A1C^-X@LQ@^#T`!/E``!0XR``
M``H!@(OB"%&$X`80H.$(L*#AO/G_ZP`P4.("```*`##3Y0``4^,$```:!`"5
MY```4.,3```*`8"(XO+__^KE^/_K`%!0XNC__PKX_O_J=_[_Z]PAG^5\,9_E
M`B"/X`,PDN<`()/E%#&=Y0(@,^``,*#C50``&@4`H.%'WXWB\$^]Z-3X_^H-
M`*#CJ%&?Y?+X_^M3(*#C!5"/X`"`H.'L_O_J`("9Y6___^KP_?_K`*!1X@"0
MH.&%__^Z"B!0X@!@C>7@8(WB`##*X@@`H.'*^/_K!B"@XP80H.$(`*#AA/C_
MZP8`4.,"```*3`&?Y0``C^#%_?_KX""=Y4,\H.-!,T3C`P!2X7'__QJT(-;A
M2#4$XP,`4N%M__\:,B!9XNA`C>(`,,KB`!"@XP@`H.$`$(WEL?C_ZR@@H.,(
M`*#A!!"@X6OX_^LH`%#C`@``"NP`G^4``(_@K/W_Z^0`G^4`(*#CX#"?Y>`0
MG^4``(_@$"'-Y0,PC^`$`(WE`1"/X`<@H.$%`*#A`$"-Y:3X_^MZ___J!&"9
MY0``5N-$__\*!@"@X:?X_^L#`%#C0/__FIP0G^4$`$#B``"&X`$0C^"I^/_K
M``!0XP:`H`$X___J)/C_ZZ1C`0`<90$`0`$``%AC`0`8'```V!P``"`;``#T
M&P``W!L``#0:``!H`0``V!L``'1A`0"8&P``8!L``"0:``"L&0``H!@```P;
M``"P&P``R!L``)08```$&P``E!@``'09``#D7@$`F!@```P9``"H&```9!D`
M`"P6``",&```.!@``$PBG^5,,I_E`B"/X$@"G^7P0"WI#-!-X@,PDN<``(_@
M#6"@X0`PD^4$,(WE`#"@XW'X_^L&$*#A`#"0Y1P"G^5D(-/E``"/X&4@P^48
M^?_K``!0XP(```H`,-#E,0!3XV0```K@^__K]`&?Y?1!G^4``(_@8/C_ZP1`
MC^`#,*#C`2"@XP00H.$`4*#A``"0Y?SW_^L`0%#B"@``"@PPE.7$(9_E``"5
MY0`0D^4"((_@V??_ZPPPE.4`$)/E"#"1Y0$%$^-7```:H`&?Y:!!G^4``(_@
M2/C_ZP1`C^`#,*#C`2"@XP00H.$`4*#A``"0Y>3W_^L`0%#B"0``"G0!G^4&
M$*#A``"/X.GX_^L`(%#B/```"@PPE.4``)7E`!"3Y;WW_^M0`9_E4'&?Y0``
MC^`Q^/_K2!&?Y0$@H.,'<(_@`1"/X`!0D.4`0*#A!0"@X=CW_^LL(9_E`B"/
MX``0H.$%`*#AK/?_ZP`PE.48`9_E`""@XP80H.$``(_@92##Y<OX_^L``%#C
M"`"'Y1$```H'':#CW_?_ZP$@@.(`,*#A$0!0XP$`4A,B``"*W""?Y:`PG^4"
M((_@`S"2YP`@D^4$,)WE`B`SX``PH.,8```:#-"-XO"`O>@$`)?EU?W_ZP``
M4.,(`(?EZ/__&J``G^4``(_@LO?_ZP$PT.4``%/CF/__"I;__^J(,)_E#""4
MY0,PC^`$,)/E``"2Y0`0D^6G^?_KOO__Z@``E>6V]__KI/__ZG7W_^M<()_E
M7`"?Y0(@C^```(_@!@"2Z0`0D>6;]__KX%P!`$`!``#\70$`V!4``*A=`0!L
M%P``/!<``$A=`0`8%P``U!0``.Q<`0#070$`M!8``+06``!4%```-%L!`"06
M``#\7`$`S%P!`/05``!P0"WI`$"@X3K[_^LP^__K`%"@X9G\_^L``%#C``!4
M$W"`O0@`,-3E``!3XW"`O0@@$)_E!""@XP4`H.$!$(_@'_?_ZP``4.-P@+T8
M!`"@X7!`O>BD^/_J%!0``/!/+>E3WTWBY.N?Y00PC>+@*Y_E'!"`X@[@C^!<
MP(#B`$"@X0,`H.$"()[G`""2Y40AC>4`(*#C!""1Y`$`7.$R+[_F!""`Y/K_
M_QK\`(/B#2"@X0(0H.$$P++E.#"1Y23@D>4``%+A#!"1Y0XP(^`!,"/@##`C
MX.,_H.%`,(+E\___&B!0E.F9.0?C!`"=Y8(Z1>,`8)3E$'"4Y0X0+.`#`(#@
M!1`!X`<`@.!ED:#A#A`AX`@@G>7F#8#@9H&@X0$`@.`)$"S@`R""X`80`>`.
M((+@#!`AX`(0@>`,()WEX!V!X`,@@N`,H(+@""`IX``@`N!@`:#A"2`BX`H@
M@N`0H)WEX2V"X`.@BN`)H(K@`)`HX`&0">!A$:#A")`IX`J0B>`4H)WEXIV)
MX`.@BN`(H(K@`8`@X`*`".!B(:#A`(`HX`*P(>`*@(C@&*"=Y0FP"^#IC8C@
M`Z"*X`"@BN!I`:#A`9`KX`"P(N`*D(G@'*"=Y0BP"^#HG8G@`Z"*X`&@BN!H
M$:#A`H`KX`&P(.`*@(C@(*"=Y0FP"^#IC8C@`Z"*X`*@BN!I(:#A`)`KX`*P
M(>`*D(G@)*"=Y0BP"^#HG8G@`Z"*X`"@BN!H`:#A`8`KX`"P(N`*@(C@**"=
MY0FP"^#IC8C@`Z"*X`&@BN!I$:#A`I`KX`&P(.`*D(G@+*"=Y0BP"^#HG8G@
M`Z"*X`*@BN!H(:#A`(`KX`*P(>`*@(C@,*"=Y0FP"^#IC8C@`Z"*X`"@BN!I
M`:#A`9`KX`"P(N`*D(G@-*"=Y0BP"^#HG8G@`Z"*X`&@BN!H$:#A`H`KX`&P
M(.`*@(C@.*"=Y0FP"^#IC8C@`Z"*X`*@BN!I(:#A`)`KX`*P(>`*D(G@/*"=
MY0BP"^#HG8G@`Z"*X`"@BN!H`:#A`8`KX`"P(N`*@(C@0*"=Y0FP"^#IC8C@
M`Z"*X`&@BN!I$:#A`I`KX`&P(.`*D(G@1*"=Y0BP"^#HG8G@`Z"*X`*@BN!H
M(:#A`(`KX`J`B.!(H)WEZ8V(X`.@BN```(K@`J`AX`F@"N!ID:#A`:`JX`"@
MBN!,`)WEZ*V*X`,`@.`!`(#@"1`BX`@0`>!H@:#A`A`AX``0@>!0`)WEZAV!
MX`,P@.`(`"G@"@``X`(@@^`)`"#@H3L.XP(`@.!4()WEV3Y&XVJAH.$#((+@
MX0V`X`F0@N!8()WE`R""X`@@@N`*@"C@`8`HX`B`B>!AD:#A7!"=Y>"-B.`#
M$('@"A"!X`F@*N``H"K@8`&@X0J@@N!@()WEZ*V*X`,@@N`)((+@`)`IX`B0
M*>!H@:#A"9"!X&00G>7JG8G@`Q"!X``0@>`(`"#@"@`@X&JAH.$``(+@:""=
MY>D-@.`#((+@""""X`J`*.`)@"C@:9&@X0B`@>!L$)WEX(V(X`,0@>`*$('@
M":`JX`"@*N!@`:#A"J""X'`@G>7HK8K@`R""X`D@@N``D"G@")`IX&B!H.$)
MD('@=!"=Y>J=B>`#$('@`!"!X`@`(.`*`"#@:J&@X0``@N!X()WEZ0V`X`,@
M@N`(((+@"H`HX`F`*.!ID:#A"("!X'P0G>7@C8C@`Q"!X`H0@>`)H"K@`*`J
MX&`!H.$*H(+@@""=Y>BMBN`#((+@"2""X`"0*>`(D"G@:(&@X0F0@>"$$)WE
MZIV)X&JQH.$#$('@`!"!X`@`(.`*`"#@`"""X.FM@N"(()WE`R""X`@@@N`+
M@"C@"0`HX&F1H.$`$('@C`"=Y>J-@>`)$"O@`P"`X`H0(>`+`(#@D+"=Y6JA
MH.$!$(+@`["+X.@=@>`)L(O@"I`IX`@@*>!H@:#A`B"`X.&=@N"4()WE`R""
MX`H@@N`(H"K@`0`JX)B@G>5A$:#A``"+X`.@BN#I#8#@"*"*X`&`*.`)@"C@
M:9&@X0B`@N"<()WEX(V(X*2PG>4#((+@`2""X`D0(>``$"'@8`&@X0&@BN``
M$"G@Z*V*X`@0(>`!((+@:(&@X>H=@N"@()WE`R""X`@P(.`)((+@:I&@X0.@
M*N#</`OC&S](XPH@@N`#L(O@":"(X0"PB^"H`)WEX2V"X`&@"N`#`(#@81&@
MX0@`@.`)@`C@"*"*X0&`B>$+H(K@`H`(X`&P">#BK8K@"X"(X;"PG>4``(C@
M8B&@X>J-@."L`)WE`["+X`,`@.`!L(O@"9"`X`(`@>$*``#@`A`!X`$0@.%J
MH:#A"9"!X`H0@N'H#8G@M)"=Y0@0`>!H@:#A`Y")X`*0B>`*(`+@`B"!X0@0
MBN$+L(+@`!`!X`@@"N#@O8O@`A"!X;@@G>4)$('@O)"=Y6`!H.$#((+@"J""
MX`.0B>``((CA")")X`L@`N``@`C@ZQV!X`B`@N%KL:#A"J"(X`L@@.%A@:#A
MX:V*X`$@`N#`$)WE`Q"!X``0@>`+``#@``""X0@@B^$)`(#@"B`"X`B0"^#J
M#8#@"2""X<B0G>4!$(+@Q""=Y6JAH.$#D(G@`R""X`B0B>`+L(+@"B"(X0`@
M`N`*@`C@X!V!X`B`@N%@`:#A"["(X``@BN%A@:#AX;V+X`$@`N#,$)WE`Q"!
MX`H0@>``H`K@"J""X0@@@.$)D(K@"R`"X`B@`.#KG8G@"B""X=2@G>4!$(+@
MT""=Y6NQH.$#H(K@`R""X`B@BN```(+@"R"(X0D@`N`+@`C@Z1V!X`B`@N%I
MD:#A``"(X`D@B^'AC8#@`2`"X&$!H.'8$)WE`Q"!X`L0@>`)L`O@"[""X0`@
MB>$*H(O@""`"X`"P">#HK8K@"R""X>"PG>4!$(+@W""=Y6B!H.$#L(O@`R""
MX`"PB^`)D(+@"""`X0H@`N`(``#@ZAV!X```@N%JH:#A"9"`X`H@B.%A`:#A
MX9V)X`$@`N#D$)WE`Q"!X`@0@>`*@`C@"(""X0`@BN$+@(C@"2`"X`"P"N#I
MC8C@"R""X>RPG>4!((+@Z!"=Y6F1H.$#L(O@`Q"!X`"PB^`*H('@"1"`X0@0
M`>`)``#@Z"V"X```@>$*H(#@:(&@X>(-BN#PH)WE"!")X0,PBN`"$`'@"3"#
MX&(AH.$(D`G@`J"(X0D0@>$`H`K@"Q"!X`*P".#@'8'@"Z"*X6"1H.$#,(K@
M]`"=Y>&M@^#6,0SC8CI,XP,`@.!AL:#A"("`X/@`G>4#`(#@`@"`X`D@(N`!
M("+@_!"=Y0*`B.`+("G@ZHV(X`H@(N`#$('@:J&@X0D0@>`*D"O@")`IX`(`
M@.`)D('@!!&=Y0`AG>7H#8#@`Q"!X&B!H.$*$('@`R""X`B@*N`+((+@`*`J
MX."=B>`*H(+@""&=Y6`!H.'IK8K@`R""X`@@@N``@"C@"8`HX&F1H.$(@('@
M#!&=Y>J-B.`#$('@`!"!X`D`(.`*`"#@:J&@X0``@N`0(9WEZ`V`X`,@@N`)
M((+@"I`IX`B0*>!H@:#A"9"!X!01G>7@G8G@`Q"!X`H0@>`(H"K@`*`JX&`!
MH.$*H(+@&"&=Y>FMBN`#((+@""""X`"`*.`)@"C@:9&@X0B`@>`<$9WEZHV(
MX`,0@>``$('@"0`@X`H`(.!JH:#A``""X"`AG>7H#8#@`R""X`D@@N`*D"G@
M")`IX&B!H.$)D('@)!&=Y>"=B>`#$('@"A"!X`B@*N``H"K@8`&@X0J@@N`H
M(9WEZ:V*X`,@@N`(((+@`(`HX`F`*.!ID:#A"("!X"P1G>7JC8C@`Q"!X``0
M@>`)`"#@"@`@X&JAH.$``(+@,"&=Y>@-@.`#((+@"2""X`J0*>`(D"G@:(&@
MX0D0@>`TD9WEX!V!X`.0B>`*D(G@"*`JX`"@*N!@`:#A"B""X#BAG>7A+8+@
M`Z"*X`B@BN``@"C@`8`HX&$1H.$(D(G@/(&=Y>*=B>`#@(C@`("(X`$`(.`"
M`"#@8B&@X0``BN`"<(?@Z0V`X!!PA.5@P8S@","$Y4#!G>4#,(S@!C"#X`$P
M@^`"$"'@"1`AX&F1H.$!$(C@"2`BX.`=@>``("+@`C"#X$@@G^4!4(7@X1V#
MX#@PG^4"((_@!%"$Y0G@CN``$(3E#."$Y0,PDN<`()/E1#&=Y0(@,^``,*#C
M`0``&E/?C>+PC[WH1O3_Z]!9`0!``0``+$X!`!!`+>E@`*#COO3_ZP`@H.,!
MPP+CB1L*XT7'1N/-'T[C`,"`Y?[,#>,$$(#ENLA)XW84!>,(P(#E,A!!XQ0@
M@.4,$(#E\!$.XQ@@@.72$TSC7""`Y1`0@.40@+WH\$<MZ0*0H.$4,)#E@B&@
MX0!0H.$!0*#A`C"3X!@@D.44,(#E'("%XEP`D.4!(((BJ2Z"X!@@A>4``%#C
M#@``"D!@8.(``(C@!@!9X0E@H+$&(*#A$/3_ZUPPE>4#,(;@7#"%Y4``4^/P
MA[T8!0"@X0:02>`&0(3@R?S_ZS\`6>,>``#:0)!)XBECH.$!<(;B!W.$X`00
MH.%`0(3B"#"@X0#@D>40$('B#,`1Y1`P@^((`!'E!"`1Y00`4>$0X`/E#,`#
MY0@``^4$(`/E\___&@4`H.$!0*#AL?S_ZP<`5.'K__\:!I-)X`D@H.$'$*#A
M"`"@X>CS_^M<D(7E\(>]Z`1PH.'W___J\$$MZ1QP@>(4()'E`4"@X1A@D>4`
M4*#ATC'EYS*/O^8!((/B?Q#@XS@`4N,V;[_F`@"'X`,0Q^=```#:0"!BX@`0
MH./P\__K!`"@X9+\_^M0`,#R+#"$X@\*1_0/"D/T/#"$X@\*0_1,,(3B#P=#
M]`0`H.%48(3E6("$Y8;\_^L#,-3E!`"@X0`PQ>6R,-3A`3#%Y0`PE.4C-*#A
M`C#%Y0`PE.4#,,7E!S#4Y00PQ>6V,-3A!3#%Y00PE.4C-*#A!C#%Y00PE.4'
M,,7E"S#4Y0@PQ>6Z,-3A"3#%Y0@PE.4C-*#A"C#%Y0@PE.4+,,7E#S#4Y0PP
MQ>6^,-3A#3#%Y0PPE.4C-*#A#C#%Y0PPE.4/,,7E$S#4Y1`PQ>6R,=3A$3#%
MY1`PE.4C-*#A$C#%Y1`PE.43,,7E\$&]Z'GS_^HX(&+B`!"@XZ_S_^O'___J
M7#"?Y1!`+>D#,(_@5$"?Y20@T^4$0(_@``!2XQ"`O1A$()_E`1"@XR00P^4"
M,)3G``!3XP(```HP,)_E`P"?YTSS_^LH,)_E`S"4YP``4^,0@+T('`"?Y1!`
MO>@``(_@N?/_ZBA-`0`@2P$`'`$``'!,`0!4`0``:$4``#P0G^4\,)_E`1"/
MX`,PC^``(-'E``!2XQ[_+Q$H()_E`0"@XP``P>4",)/G``!3XQ[_+P$4`)_E
M!!"!X@``C^"K\__JK$P!`*Q*`0!8`0``#$4``%3"G^54,I_E<$`MZ0S`C^`@
MT$WB2%*?Y10`C>44`(WB$!"-Y1`0C>(,((WE#""-X@,PG.<%4(_@`#"3Y1PP
MC>4`,*#C=_/_ZQ@BG^48,I_E`B"5YP,`E><"$*#A??/_ZP@RG^4#,)7G`$#3
MY0``5.-2```*^`&?Y0``C^"]\__K%&"=Y0`@D.4$`(;B!P%PXP-@AN)&,]+E
M`S"#XT8SPN5C``"*``&@X5+S_^O$(9_E$$"=Y0(@C^"\$9_E`1"/X`0`@N4`
M,*#A`""4Y0`@@.6H(9_E`B"/X`0@@.6@(9_E%`"=Y0(@E><!`%#C#!"#Y0`@
MDN4(((/E4@``V@00A.(,P(/B`$&$X`3@D>0!`%3A!."LY?O__QH#`(#B9$&?
MY0`0H.,`$(WE!B"@X0`1@^<$0(_@4!&?Y0P`E.4!$(_@6?/_ZP``4.,I```*
M/%&?Y1A@C>(%4(_@#`"5Y0?S_^L&$*#A`$"@X20!G^4``(_@+O3_ZP``4.,@
M```*%#&?Y0,PC^`,`)/E[?+_ZS3S_^L$(9_EQ#"?Y0(@C^`#,)+G`""3Y1PP
MG>4"(#/@`#"@XR@``!H$`*#A(-"-XG"`O>CW\O_KU""?Y0(@C^```%#C#`""
MY1T```K-\O_KP`"?Y0``C^!C\__K`#"0Y>9%P^6?___J#`"4Y4;S_^O2___J
M"`"5Y0``4.,!```*@_O_Z]G__^J,`)_E!A"@X0``C^`"]/_K``!0XP@`A>72
M__\*]?__ZG`PG^5P`)_E`Q"5YP``C^#]\O_K!`"@X[+__^H!`*#CBO+_Z\OR
M_^M82@$`0`$``#!*`0!0`0``8`$``"P!```<2P$`U$L!`$`%```D!0``3`$`
M`%A+`0"TV/__-$L!`#P"```(2P$`S$@!`,!*`0"T20$`+`$``$@!``#X`@``
M<'-?<W1R:6YG<R!M:7-S:6YG"@`O=&UP+P```"X```!005)?5$U01$E2``!4
M14U01$E2`%1-4`!54T52`````%5315).04U%`````"5S+R5S````+W!R;V,O
M8W5R<')O8R]E>&4```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`````4$%27U1%35``````4$%27U!23T=.04U%
M`````#H````E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`
M````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)5
M1P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.`````#$```!L<V5E:R!F86EL960`````<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P``
M``!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````'-H
M;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E
M<W1E;7`M)74M)74E<P`````8````<&5R;``````P````4$%2.CI086-K97(Z
M.E9%4E-)3TX`````,2XP-3D```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H
M95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<
M;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C
M:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T
M(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D
M8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M
M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU
M;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D
M8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!
M4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)
M0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N
M:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA
M;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M2
M96UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F
M("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP
M*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.
M2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I
M;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D
M9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF
M,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*
M?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D
M("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H
M*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?
M=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I
M;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H
M<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N
M)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-
M04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D[
M"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G
M:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET
M:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&
M2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!
M0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M
M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA
M<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D
M1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F
M9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U
M=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O
M9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@
M,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F
M:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U
M;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F
M:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D
M=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S
M*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B
M)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;
M0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q
M("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@
M*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L
M($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I
M92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ
M+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY
M("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO
M="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L
M;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I
M;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I
M;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D
M97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O
M(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13
M=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z
M("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H
M($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L
M:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@
M*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y
M?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I
M<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL
M87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2![
M"FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG
M($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968[
M"F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T
M:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\
M96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T
M96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@
M*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]
M"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]
M($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C
M='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F
M<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A
M73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A
M:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J
M(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N
M+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@
M8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A
M8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T
M9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D
M9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ
M92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92![
M"F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?
M;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N
M86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF
M("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*
M?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M
M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T
M:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D
M9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B
M7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B
M=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE
M7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C
M86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?
M0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE
M7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S
M879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM
M>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D
M9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY
M("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN
M="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E
M;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F
M=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL
M;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S
M>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX[
M"GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@
M/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P
M<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2
M(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[
M(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D
M7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`````0T%#2$4```$;`SL`
M`0``'P```"R,__\8`0``A(S__S0!``#\C/__5`$``*2.__^D`0``@(___\@!
M``#XD/__]`$``)R1__\8`@``M)+__U`"``#4D___@`(``!"6__^P`@``;);_
M_]0"``#DEO__]`(``.R6__\(`P``:)G__T`#``",F?__8`,``-R9__^(`P``
M%)___[@#``"HG___V`,```R@___\`P``M*'__S0$``#,H?__3`0``"BC__^$
M!```\*G__\P$``"4K/__]`0``/"L__]`!0``\+C__W0%``!,N?__C`4``%2Z
M__^P!0``I+O__X0!```@O/__<`$``'2\__\8!0``$``````````!>E(``GP.
M`1L,#0`8````&`````R+__]8`````$@.$(0$A0.&`HX!'````#0```!(B___
M>`````!2#AB$!H4%A@2'`X@"C@$8````5````*"+__^H`0```$8."(<"C@%$
M#A``$````'````"HNO__5``````````<````A````!BZ__]\`````$0."(0"
MC@%JSL0.`````"````"D````^(S__]P`````0@X@A`B%!X8&AP6(!(D#B@*.
M`2@```#(````L(W__W@!````2`X<A`>%!H8%AP2(`XD"C@%&#L`!8@H.'$(+
M(````/0```#\CO__I`````!(#@B$`HX!0@ZH`7(*#@A""P``-````!@!``!\
MC___&`$```!&#@R$`X4"C@%"#HP(1`Z8"`)4"@X,0@M:"@X,0L[%Q`X`0@L`
M```L````4`$``%R0__\@`0```$(.%(0%A02&`X<"C@%&#I0(1`Z@"`)P"@X4
M0@L````L````@`$``$R1__\\`@```$(.((0(A0>&!H<%B`2)`XH"C@%&#B@"
MG@H.($(+```@````L`$``%B3__]<`````$H.$(0$A0.&`HX!5L[&Q<0.```<
M````U`$``)"3__]X`````$0.#(0#A0*.`40.(&@.#!````#T`0``Z)/__P@`
M````````-`````@"``#<D___?`(```!&#B2$"84(A@>'!H@%B02*`XL"C@%$
M#M0)1`[@"0)`"@XD0@L````<````0`(``""6__\D`````$(."(0"C@%.SL0.
M`````"0```!@`@``));__U``````0@X(A`*.`58*SL0.`$(+1`K.Q`X`1`LL
M````B`(``$R6__\X!0```$@.$(0$A0.&`HX!0@X8`T0""@X00L[&Q<0.`$(+
M```<````N`(``%2;__^4`````$H.!(X!0@X0<@H.!$(+`"````#8`@``R)O_
M_V0`````1`X0@`2!`X("@P%&#A2.!4(.(#0```#\`@``")S__Z@!````0@XD
MA`F%"(8'AP:(!8D$B@.+`HX!0@ZD@`1$#L"`!`*@"@XD0@L`%````#0#``!X
MG?__&`````!"#@B$`HX!-````$P#``!XG?__7`$```!$#A2$!84$A@.'`HX!
M1@XH>`H.%$+.Q\;%Q`X`0@M<"@X40@L```!$````A`,``)R>___(!@```$P.
M)(0)A0B&!X<&B`6)!(H#BP*.`48.P`(#'@$*#B1""P-&`0H.)$+.R\K)R,?&
MQ<0.`$(+```D````S`,``!RE__^D`@```$H.%(0%A02&`X<"C@%"#B`"W@H.
M%$(+(````/0#``"8I___7`````!"#A"$!(4#A@*.`6C.QL7$#@``)````!@$
M``!4M___M`(```!&#A"$!(4#A@*.`40.,`+4"@X00@L``#````!`!```J*?_
M_P`,````0@XDA`F%"(8'AP:(!8D$B@.+`HX!0@[P`@/R!0H.)$(+```4````
M=`0``'2S__]<`````$(."(0"C@$@````C`0``+BS__\(`0```$(.((0(A0>&
M!H<%B`2)`XH"C@$L````L`0``)RT__]0`0```$(.&(0&A06&!(<#B`*.`0*<
M"L[(Q\;%Q`X`0@L`````````S$8``%!&`````````0````$````!````RP(`
M``$```#5`@```0```.H"```!````"0,```\```"B!```&0```)"0`0`;````
M!````!H```"4D`$`'`````0````$````>`$```4```!T"P``!@```+0$```*
M````ZP0```L````0````%0`````````#````C)$!``(````8`@``%````!$`
M```7````>!$``!$```!@$```$@```!@!```3````"````/O__V\````(^O__
M;Q<`````````````````````````````````````````````````````````
MG)`!````````````D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0
M$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3
M``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,`
M`)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``
MD!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0
M$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3``"0$P``D!,``)`3
M``"0$P``D!,``)B0`0````````````````"0D`$`````````````````P),!
M````````````E)`!``````!$DP$`````````````````G)`!``````"$DP$`
M``````"3`0"<-```@),!``23`0`*4$%2+G!M"@````#H20``\$D```````#T
M20``^$D```!*``!T2@``"$H````````,2@``%$H````````H30``1T-#.B`H
M3F5T0E-$(&YB,R`R,#(S,3`P."D@,3`N-2XP`$=#0SH@*&YB,R`R,#(S,3`P
M."D@,3`N-2XP`"1.971"4T0Z(&-R=#`N4RQV(#$N-"`R,#$X+S$Q+S(V(#$W
M.C,W.C0T(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=#`M8V]M;6]N+F,L=B`Q
M+C(W(#(P,C(O,#8O,C$@,#8Z-3(Z,3<@<VMR;&P@17AP("0`)$YE=$)31#H@
M8W)T:2Y3+'8@,2XQ(#(P,3(O,#@O,3,@,#(Z-#DZ,#0@;6%T="!%>'`@)``D
M3F5T0E-$.B!C<G1B96=I;BYC+'8@,2XQ-R`R,#$X+S$R+S(X(#$X.C$W.C$Q
M(&-H<FES=&]S($5X<"`D`"1.971"4T0Z(&-R=&5N9"Y3+'8@,2XR(#(P,3,O
M,3(O,C`@,34Z,S4Z-#@@:F]E<F<@17AP("0`\<\"``````````````````@`
M```(````"`````@````;`````0``````````*BHJ($YO($QA8F5L(%!R;W9I
M9&5D("HJ*@``\<\"``````````````````@````(````"`````@````;````
M`0``````````*BHJ($YO($QA8F5L(%!R;W9I9&5D("HJ*@!!,@```&%E86)I
M``$H````!3<M00`&"@=!"`$)`@H##`$2!!0!%0$7`Q@!&@(<`2(!1`$`+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N;F5T8G-D+FED96YT`"YN;W1E+FYE=&)S
M9"YP87@`+FYO=&4N;F5T8G-D+FUA<F-H`"YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N<F5L+F1Y;@`N<F5L+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y
M;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y354Y77V-T9@`N05)-
M+F%T=')I8G5T97,`+FYO:6YI=```````````````````````````````````
M``````````````````````L````!`````@```!0!```4`0``%P``````````
M`````0`````````3````!P````(````L`0``+`$``!@```````````````0`
M````````)@````<````"````1`$``$0!```4```````````````$````````
M`#<````'`````@```%@!``!8`0``(```````````````!`````````!*````
M!0````(```!X`0``>`$``#P#```&``````````0````$````4`````L````"
M````M`0``+0$``#`!@``!P````,````$````$````%@````#`````@```'0+
M``!T"P``ZP0``````````````0````````!@````"0````(```!@$```8!``
M`!@!```&``````````0````(````:0````D```!"````>!$``'@1```8`@``
M!@```!,````$````"````&T````!````!@```)`3``"0$P``.`,`````````
M````!`````0```!R`````0````8```#(%@``R!8```PS``````````````0`
M````````>`````$````"````U$D``-1)``#70``````````````$````````
M`(`````!`````@```*R*``"LB@``!`$`````````````!`````````".````
M`0````(```"PBP``L(L``.`$``````````````0`````````F`````X````#
M````D)`!`)"0```$```````````````$````!````*0````/`````P```)20
M`0"4D```!```````````````!`````0```"P`````0````,```"8D`$`F)``
M``0```````````````0`````````M0````8````#````G)`!`)R0``#P````
M!P`````````$````"````+X````!`````P```(R1`0",D0``=`$`````````
M````!`````0```##`````0````,`````DP$``),``$@```````````````0`
M````````R0````@````#````@),!`$B3``!$``````````````!`````````
M`,X````!````,`````````!(DP``/0```````````````0````$````?````
M`0```#``````````A9,``!\!``````````````$````!````UP````$`````
M`````````*24``"/```````````````$`````````.$````#``!P````````
M```SE0``,P```````````````0````````#Q`````0````$```#$DP$`9I4`
M``````````````````$``````````0````,``````````````&:5``#Y````
0```````````!````````````
